@@ -8,5 +8,5 @@ def get_dict_key_from_value(source_dict, value_to_find):
     for key, value in source_dict.items():
         if value_to_find.lower() == value.lower():
             return key
-    raise Exception('Key: {}, not found in dict: {}'.format(value_to_find, source_dict)
+    raise Exception('Key: {}, not found in dict: {}'.format(value_to_find, source_dict))
 
