@@ -1,5 +1,4 @@
-
-Capec ={
+CAPEC = {
    '1': 'Abuse of Functionality',
    '2': 'Spoofing',
    '3': 'Probabilistic Techniques',
